[**@notabene/javascript-sdk**](../../README.md)

***

[@notabene/javascript-sdk](../../modules.md) / [notabene](../README.md) / ConnectionManager

# Class: ConnectionManager

Manages encrypted connections using Cloudflare Durable Objects

## Constructors

### new ConnectionManager()

> **new ConnectionManager**(`endpoint`): [`ConnectionManager`](ConnectionManager.md)

#### Parameters

##### endpoint

`string`

#### Returns

[`ConnectionManager`](ConnectionManager.md)

#### Defined in

[utils/connections.ts:30](https://gitlab.com/notabene/open-source/javascript-sdk/-/blob/69cd8d08514af027712db73539fbd0247649c123/src/utils/connections.ts#L30)

## Methods

### close()

> **close**(`id`): `Promise`\<`void`\>

Closes a connection

#### Parameters

##### id

`string`

Connection ID

#### Returns

`Promise`\<`void`\>

#### Defined in

[utils/connections.ts:165](https://gitlab.com/notabene/open-source/javascript-sdk/-/blob/69cd8d08514af027712db73539fbd0247649c123/src/utils/connections.ts#L165)

***

### create()

> **create**\<`T`\>(`data`, `metadata`): `Promise`\<[`ConnectionResponse`](../interfaces/ConnectionResponse.md)\<`T`\>\>

Creates a new encrypted connection

#### Type Parameters

• **T** *extends* [`ComponentRequest`](../../types/interfaces/ComponentRequest.md)

#### Parameters

##### data

[`ConnectionData`](../interfaces/ConnectionData.md)\<`T`\>

The component request data to encrypt and store

##### metadata

[`ConnectionMetadata`](../interfaces/ConnectionMetadata.md)

#### Returns

`Promise`\<[`ConnectionResponse`](../interfaces/ConnectionResponse.md)\<`T`\>\>

Promise resolving to connection details including ID, version, and encryption key

#### Defined in

[utils/connections.ts:40](https://gitlab.com/notabene/open-source/javascript-sdk/-/blob/69cd8d08514af027712db73539fbd0247649c123/src/utils/connections.ts#L40)

***

### get()

> **get**\<`T`\>(`id`, `key`): `Promise`\<[`ConnectionResponse`](../interfaces/ConnectionResponse.md)\<`T`\>\>

Retrieves and decrypts connection data

#### Type Parameters

• **T** *extends* [`ComponentRequest`](../../types/interfaces/ComponentRequest.md)

#### Parameters

##### id

`string`

Connection ID

##### key

`string`

Encryption key from previous create/update operation

#### Returns

`Promise`\<[`ConnectionResponse`](../interfaces/ConnectionResponse.md)\<`T`\>\>

Promise resolving to connection details including decrypted data

#### Defined in

[utils/connections.ts:128](https://gitlab.com/notabene/open-source/javascript-sdk/-/blob/69cd8d08514af027712db73539fbd0247649c123/src/utils/connections.ts#L128)

***

### update()

> **update**\<`T`\>(`id`, `data`, `version`): `Promise`\<[`ConnectionResponse`](../interfaces/ConnectionResponse.md)\<`T`\>\>

Updates an existing connection with new encrypted data

#### Type Parameters

• **T** *extends* [`ComponentRequest`](../../types/interfaces/ComponentRequest.md)

#### Parameters

##### id

`string`

Connection ID

##### data

[`ConnectionData`](../interfaces/ConnectionData.md)\<`T`\>

New data to encrypt and store

##### version

`number`

Current version number

#### Returns

`Promise`\<[`ConnectionResponse`](../interfaces/ConnectionResponse.md)\<`T`\>\>

Promise resolving to updated connection details including new encryption key

#### Defined in

[utils/connections.ts:84](https://gitlab.com/notabene/open-source/javascript-sdk/-/blob/69cd8d08514af027712db73539fbd0247649c123/src/utils/connections.ts#L84)
