[**@notabene/javascript-sdk**](../../README.md)

***

[@notabene/javascript-sdk](../../modules.md) / [types](../README.md) / ProofTypes

# Enumeration: ProofTypes

Types of ownership proofs supported by the system

## Remarks

Supported proof types:
- SelfDeclaration: User self-declares ownership without cryptographic proof
- EIP191: Ethereum personal signature following EIP-191 standard
- SIWE: Sign-In with Ethereum message signature (EIP-4361)
- EIP712: Ethereum typed data signature following EIP-712 standard
- BIP137: Bitcoin message signature following BIP-137
- BIP322: Bitcoin message signature following BIP-322
- TIP191: Tron message signing
- ED25519: Ed25519 signature (used in Solana)
- XRP_ED25519: Ed25519 signature (used in XRP)
- XLM_ED25519: Ed25519 signature (used in Stellar)
- XPUB: Extended public key signature for HD wallets
- MicroTransfer: Proof via small blockchain transaction
- Screenshot: Image proof of ownership/access
- CIP8: Cardano message signing standard (CIP-8)

## See

 - [SignatureProof](../interfaces/SignatureProof.md) For signature-based proofs
 - [DeclarationProof](../interfaces/DeclarationProof.md) For self-declaration proofs
 - [MicroTransferProof](../interfaces/MicroTransferProof.md) For transaction-based proofs
 - [ScreenshotProof](../interfaces/ScreenshotProof.md) For screenshot proofs

## Enumeration Members

### BIP137

> **BIP137**: `"bip-137"`

#### Defined in

[types.ts:1077](https://gitlab.com/notabene/open-source/javascript-sdk/-/blob/69cd8d08514af027712db73539fbd0247649c123/src/types.ts#L1077)

***

### BIP137\_XPUB

> **BIP137\_XPUB**: `"xpub"`

#### Defined in

[types.ts:1079](https://gitlab.com/notabene/open-source/javascript-sdk/-/blob/69cd8d08514af027712db73539fbd0247649c123/src/types.ts#L1079)

***

### BIP322

> **BIP322**: `"bip-322"`

#### Defined in

[types.ts:1078](https://gitlab.com/notabene/open-source/javascript-sdk/-/blob/69cd8d08514af027712db73539fbd0247649c123/src/types.ts#L1078)

***

### CIP8

> **CIP8**: `"cip-8"`

#### Defined in

[types.ts:1084](https://gitlab.com/notabene/open-source/javascript-sdk/-/blob/69cd8d08514af027712db73539fbd0247649c123/src/types.ts#L1084)

***

### Connect

> **Connect**: `"connect"`

#### Defined in

[types.ts:1087](https://gitlab.com/notabene/open-source/javascript-sdk/-/blob/69cd8d08514af027712db73539fbd0247649c123/src/types.ts#L1087)

***

### ED25519

> **ED25519**: `"ed25519"`

#### Defined in

[types.ts:1081](https://gitlab.com/notabene/open-source/javascript-sdk/-/blob/69cd8d08514af027712db73539fbd0247649c123/src/types.ts#L1081)

***

### EIP1271

> **EIP1271**: `"eip-1271"`

#### Defined in

[types.ts:1076](https://gitlab.com/notabene/open-source/javascript-sdk/-/blob/69cd8d08514af027712db73539fbd0247649c123/src/types.ts#L1076)

***

### EIP191

> **EIP191**: `"eip-191"`

#### Defined in

[types.ts:1074](https://gitlab.com/notabene/open-source/javascript-sdk/-/blob/69cd8d08514af027712db73539fbd0247649c123/src/types.ts#L1074)

***

### EIP712

> **EIP712**: `"eip-712"`

#### Defined in

[types.ts:1075](https://gitlab.com/notabene/open-source/javascript-sdk/-/blob/69cd8d08514af027712db73539fbd0247649c123/src/types.ts#L1075)

***

### MicroTransfer

> **MicroTransfer**: `"microtransfer"`

#### Defined in

[types.ts:1085](https://gitlab.com/notabene/open-source/javascript-sdk/-/blob/69cd8d08514af027712db73539fbd0247649c123/src/types.ts#L1085)

***

### Screenshot

> **Screenshot**: `"screenshot"`

#### Defined in

[types.ts:1086](https://gitlab.com/notabene/open-source/javascript-sdk/-/blob/69cd8d08514af027712db73539fbd0247649c123/src/types.ts#L1086)

***

### SelfDeclaration

> **SelfDeclaration**: `"self-declaration"`

#### Defined in

[types.ts:1071](https://gitlab.com/notabene/open-source/javascript-sdk/-/blob/69cd8d08514af027712db73539fbd0247649c123/src/types.ts#L1071)

***

### SIWE

> **SIWE**: `"siwe"`

#### Defined in

[types.ts:1072](https://gitlab.com/notabene/open-source/javascript-sdk/-/blob/69cd8d08514af027712db73539fbd0247649c123/src/types.ts#L1072)

***

### SIWX

> **SIWX**: `"siwx"`

#### Defined in

[types.ts:1073](https://gitlab.com/notabene/open-source/javascript-sdk/-/blob/69cd8d08514af027712db73539fbd0247649c123/src/types.ts#L1073)

***

### TIP191

> **TIP191**: `"tip-191"`

#### Defined in

[types.ts:1080](https://gitlab.com/notabene/open-source/javascript-sdk/-/blob/69cd8d08514af027712db73539fbd0247649c123/src/types.ts#L1080)

***

### XLM\_ED25519

> **XLM\_ED25519**: `"xlm-ed25519"`

#### Defined in

[types.ts:1083](https://gitlab.com/notabene/open-source/javascript-sdk/-/blob/69cd8d08514af027712db73539fbd0247649c123/src/types.ts#L1083)

***

### XRP\_ED25519

> **XRP\_ED25519**: `"xrp-ed25519"`

#### Defined in

[types.ts:1082](https://gitlab.com/notabene/open-source/javascript-sdk/-/blob/69cd8d08514af027712db73539fbd0247649c123/src/types.ts#L1082)
